#
# spec file for package debootstrap
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Frank Lichtenheld <frank@lichtenheld.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           debootstrap
Version:        1.0.72
Release:        8.5
Summary:        Bootstrap a basic Debian system
License:        MIT
Group:          Development/Tools/Other
Url:            https://packages.debian.org/debootstrap
Source0:        http://httpredir.debian.org/debian/pool/main/d/%{name}/%{name}_%{version}.tar.gz
Source1:        devices.tar.gz
Patch0:         %{name}-norootforbuild.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
debootstrap is used to create a Debian base system from scratch,
without requiring the availability of dpkg or apt. It does this
by downloading .deb files from a mirror site, and carefully
unpacking them into a directory which can eventually be chrooted
into.

%prep
%setup -q
%patch0 -p1
cp -f %{SOURCE1} .

%build
# Nothing to build.

%install
%make_install
install -Dm 0644 %{name}.8 %{buildroot}%{_mandir}/man8/%{name}.8

%files
%defattr(-,root,root)
%doc README TODO debian/changelog debian/copyright
%{_sbindir}/%{name}
%{_datadir}/%{name}/
%{_mandir}/man?/%{name}.?%{?ext_man}

%changelog
* Wed Aug  5 2015 sor.alexei@meowr.ru
- Update to 1.0.72 (changes since 1.0.70):
  * Adjust sed call to render it more portable (missing ';'),
    making it work with FreeBSD sed.
  * Add (Ubuntu) wily as a symlink to gutsy.
  * Fix resolve_deps and setup_available to work in the --foreign
    case.
* Sun Jun 14 2015 sleep_walker@suse.cz
- bump to 1.0.70
  * Use tr instead of (missing in d-i) xargs (Closes:
    [#785693]). Thanks, Julian Schauder!
  * Make sure to deduplicate package list in download_release to
    avoid issues while counting downloaded packages. The failure
    path could lead to printing some strange integer (Closes:
    [#709751], #768445, #785276, #774752).  This was reported to
    mostly happen whenever --no-resolve-deps is used.
  * Add support for --force-check-gpg so that one can
    programmatically make sure keyring checks are used and that
    no fallback to an https mirror happens (Closes: #661501,
    [#733179], #775454).  * Switch default mirror from
    ftp.us.debian.org to the new, official http redirector
    service: httpredir.debian.org
  * Make it possible to override the MAKEDEV variable (Closes: #734743).
    Thanks, Wookey!
  * Update Standards to 3.9.6 (checked)
  * Support the jessie-kfreebsd suite, by using the same script as
    jessie (a symlink to sid) (Closes: #784927).
* Sat Mar 21 2015 sor.alexei@meowr.ru
- Update to 1.0.67 (changes since 1.0.65):
  * Support reproducible builds: specify a modification time on the
    tar side, and add the -n option to gzip
  * Update setup_apt_sources to look at USE_COMPONENTS if COMPONENTS
    is empty, fixing the empty sources.list bug with foreign
    architectures.
- Spec cleanup.
* Mon Nov 24 2014 sleep_walker@suse.cz
- bump to 1.0.65
  * Add support for stretch.
  * Add (Ubuntu) vivid as a symlink to gutsy.
  * Move set -e out of shebang line. Closes: #762713
  * Fix reporting of package version in retrieval and validation steps
    to cope with epochs.
  * Fix "possibly the package $pkg is at fault" warnings to account for
    changed error output in dpkg 1.17.2.
* Mon Jun  2 2014 thomasbechtold@jpberlin.de
- update to 1.0.60
  * Add (Ubuntu) utopic as a symlink to gutsy.
  * Sync deb support with latest dpkg-deb (deb#739136):
  - Add uncompressed data.tar deb member support.
  - Add uncompressed and xz control.tar deb member support.
* Sun Apr 20 2014 thomasbechtold@jpberlin.de
- update to 1.0.59
  * scripts/gutsy: Make the fake initctl pass through "initctl version"
  calls, used by such things as invoke-rc.d to figure out whether it's
  running under Upstart (lp#1182540).
  * scripts/sid, scripts/gutsy: Add a policy-rc.d, matching that in
  debian-installer-utils.  This is the primary way to disable daemon
  startup.
  * Add (Ubuntu) trusty as a symlink to gutsy.
  * When deboostrapping Debian, and the debian-archive-keyring is not
  available, switch the default mirror to a https url. This way at
  least the CA level of security is available even for users who
  have no way to check gpg keys in the WoT. The https mirror is
  currently https://mirrors.kernel.org/debian.
  * Avoid writing https urls into sources.list, as apt does not support https.
  * Install base-passwd and base-files in two calls rather than one to
  avoid problems with home-built media with different ordering in
  Packages.  Thanks to Jo Shields for pointing this out and providing
  the workaround (deb#601670, lp#1001131)
  * pkgdetails_perl: Only interpret percentages following whitespace, to
  cope with GNU wget outputting the local file name (which may contain "%%"
  due to URL-encoding) after it finishes the download (lp#1172101).
  * Install apt-transport-https if installing from an HTTPS mirror
  (lp#1135163).  It may still be necessary to copy certificates into
  place, but there's at least a reasonable chance that somebody installing
  from HTTPS may want to keep using it, and we have to install
  apt-transport-https at this point otherwise they won't be able to do
  that end-to-end.
  * Install ca-certificates as well as apt-transport-https for HTTPS
  installations.  This makes it possible to copy certificates that were
  built into the installer to /usr/local/share/ca-certificates/ and thus
  have them continue to be trusted after installation.
* Sat May 18 2013 frank.lichtenheld@sophos.com
- update to 1.0.51
  * Add (Ubuntu) saucy as a symlink to gutsy (deb#706989).
  * Clarify location of pkgdetails.c in error message (deb#708771).
  * Resolve mount point symlinks relative to the target chroot before
  unmounting them (deb#702861, deb#703037, deb#704744).
* Fri May 17 2013 frank.lichtenheld@sophos.com
- update to 1.0.50
  * Report package version information on package retrieve and validation.
  deb#697675
* Sun May  5 2013 frank.lichtenheld@sophos.com
- update to 1.0.49
  * Add support for jessie. deb#706788
* Fri Apr  5 2013 frank.lichtenheld@sophos.com
- update to 1.0.48
  * Disable InRelease support.  gpgv won't give us back the signed data, and
  full gpg is not available inside d-i (deb#703889).
  * Move extract_release_components to after signature verification.
* Tue Mar 26 2013 frank.lichtenheld@sophos.com
- update to 1.0.47
  * Properly decrypt the InRelease file when downloading from an archive
  where InRelease is used. This longstanding bug was masked by former
  APT behaviour and was revealed only with recent APT versions
  deb#703146
  * Add Requires on gpg2
* Mon Nov  5 2012 frank.lichtenheld@sophos.com
- update to 1.0.43
  * Add (Ubuntu) raring as a symlink to gutsy.
* Fri Jul  6 2012 frank.lichtenheld@sophos.com
- update to 1.0.42
  * Downgrade the absence of an InRelease file from a warning to an info
  message. lp#1017398
* Sun Jun 24 2012 frank.lichtenheld@sophos.com
- update to 1.0.41
  * Add support for InRelease files. deb#638682
* Thu May  3 2012 frank.lichtenheld@sophos.com
- Prepare for factory submission
  * Remove _service and add source file
  * Line-wrap description
* Sat Apr 28 2012 frank.lichtenheld@sophos.com
- update to 1.0.40
* Tue Mar 13 2012 frank.lichtenheld@sophos.com
- update to 1.0.39
* Fri Nov 25 2011 frank.lichtenheld@sophos.com
- update to 1.0.38
* Mon Oct 24 2011 frank.lichtenheld@sophos.com
- update to 1.0.37
* Tue Sep 20 2011 frank.lichtenheld@sophos.com
- update to 1.0.36
* Fri Aug 12 2011 flichtenheld@astaro.com
- update to 1.0.35
* Fri Jul 29 2011 flichtenheld@astaro.com
- update to 1.0.34
* Thu Jun  2 2011 flichtenheld@astaro.com
- update to 1.0.32
* Tue Mar 22 2011 flichtenheld@astaro.com
- update to 1.0.29
* Tue Feb 22 2011 flichtenheld@astaro.com
- update to 1.0.28
* Mon Feb 14 2011 flichtenheld@astaro.com
- update to 1.0.27
* Sat Jan 15 2011 flichtenheld@astaro.com
- initial packaging
